@@ -12,6 +12,8 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
+set -euo pipefail
+
 # This script is used for compilation of a specific variant.
 # Specify GOOS as $1, GOARCH as $2
 # Binaries are placed into ./bin/$GOOS-$GOARCH/docker-credential-ecr-login
@@ -20,9 +22,6 @@
 ROOT=$( cd "$( dirname "${BASH_SOURCE[0]}" )/.." && pwd )
 cd "${ROOT}"
 
-# Source the shared environment
-source ./scripts/shared_env
-
 # Export variables
 export TARGET_GOOS="$1"
 export TARGET_GOARCH="$2"
